@@ -5,7 +5,7 @@
 from __future__ import division
 import numpy as np
 from numpy.ma import masked_array
-from ..constants import g, Rd
+from ..constants import g, Rd, omega
 from ..package_tools import Exporter
 from ..units import atleast_1d, units
 
@@ -51,13 +51,14 @@ def get_wind_dir(u, v):
     Returns
     -------
     wind direction: array_like
-        The direction of the wind in degrees
+        The direction of the wind in degrees, specified as the direction from
+        which it is blowing
 
     See Also
     --------
     get_wind_components
     '''
-    wdir = 90. * units.deg - np.arctan2(v, u)
+    wdir = 90. * units.deg - np.arctan2(-v, -u)
     origshape = wdir.shape
     wdir = atleast_1d(wdir)
     wdir[wdir < 0] += 360. * units.deg
@@ -207,8 +208,8 @@ def heat_index(temperature, rh, mask_undefined=True):
     '''
 
     delta = temperature - 0. * units.degF
-    rh2 = rh ** 2
-    delta2 = delta ** 2
+    rh2 = rh * rh
+    delta2 = delta * delta
 
     # Calculate the Heat Index -- constants converted for RH in [0, 1]
     hi = (-42.379 * units.degF + 2.04901523 * delta +
@@ -255,3 +256,27 @@ def pressure_to_height_std(pressure):
     gamma = 6.5 * units('K/km')
     p0 = 1013.25 * units.mbar
     return (t0 / gamma) * (1 - (pressure / p0)**(Rd * gamma / g))
+
+
+@exporter.export
+def coriolis_parameter(latitude):
+    r'''Calculate the coriolis parameter at each point.
+
+    The implementation uses the formula outlined in [8].
+
+    Parameters
+    ----------
+    latitude : array_like
+        Latitude at each point
+
+    Returns
+    -------
+    array_like
+        The corresponding coriolis force at each point
+
+    References
+    ----------
+    .. [8] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
+            Survey. 370-371.
+    '''
+    return 2. * omega * np.sin(latitude)
