@@ -3,10 +3,11 @@
 # SPDX-License-Identifier: BSD-3-Clause
 
 # Trigger matplotlib wrappers
-from . import _mpl  # noqa
+from . import _mpl  # noqa: F401
+
+from .skewt import *  # noqa: F403
+from .station_plot import *  # noqa: F403
 
-from .skewt import *  # noqa
-from .station_plot import *  # noqa
 __all__ = []
 __all__.extend(skewt.__all__)  # pylint: disable=undefined-variable
 __all__.extend(station_plot.__all__)  # pylint: disable=undefined-variable
